@@ -1,10 +1,10 @@
 use quick_protobuf::deserialize_from_slice;
 use solana_program::account_info::AccountInfo;
 use solana_program::program_error::ProgramError;
-use switchboard_protos::protos::aggregator_state::AggregatorState;
 use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 use solana_program::pubkey::Pubkey;
 
+pub use switchboard_protos::protos::aggregator_state::AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::RoundResult;
 
 /// Returns whether the current open round is considered valid for usage.
@@ -19,8 +19,8 @@ pub fn is_current_round_valid(aggregator: &AggregatorState) -> Result<bool, Prog
         return Ok(false);
     }
     // Taking account for negative feed values.
-    let max_resp: f64 = 1.0 * round.min_response.abs().max(round.max_response.abs());
-    let min_resp: f64 = 1.0 * round.min_response.abs().min(round.max_response.abs());
+    let max_resp: f64 = 1.0 * round.max_response;
+    let min_resp: f64 = 1.0 * round.min_response;
     if min_resp / max_resp * 100.0 < configs.min_round_agreement_percentage.into() {
         return Ok(false);
     }
